

# ComputeTS: Function library
![](https://img.shields.io/npm/types/@compute.ts/boolean)
![](https://img.shields.io/npm/v/@compute.ts/boolean)
![](https://img.shields.io/npm/l/@compute.ts/boolean)
![](https://img.shields.io/badge/coverage-91,07%25-4cc41f.svg) 

## Presentation
The engine is based on incremental computation algorithms. When a calculation is submitted to the engine, all the computed values are memorized. So, if you change some variable and query an evaluation, the engine is able to compute the result very fast because it recomputes only what has changed.


## Libraries
The API provides several libraries that each comes with dozens of operators.
- [@compute.ts/boolean](https://www.npmjs.com/package/@compute.ts/boolean)
- [@compute.ts/number](https://www.npmjs.com/package/@compute.ts/number)
- [@compute.ts/string](https://www.npmjs.com/package/@compute.ts/string)
- [@compute.ts/date](https://www.npmjs.com/package/@compute.ts/date)
- [@compute.ts/dictionary](https://www.npmjs.com/package/@compute.ts/dictionary)
- [@compute.ts/math](https://www.npmjs.com/package/@compute.ts/math)
- [@compute.ts/structural](https://www.npmjs.com/package/@compute.ts/structural)



## Imports
### Typescript
```typescript
import {/* required operators */} from '@compute.ts/function';
```

### Javascript
```javascript
const {/* required operators */} = require('@compute.ts/function');
```

## Operators

### Function

<code>Function(value) ➜ x<sub>function</sub></code>  

<code>Function() ➜ x<sub>function</sub></code>

The **Function** operator allows you to create a boolean expression which evals to the given value. If no value is provided the expression is a variable of the model

```typescript
import {Function} from "@compute.ts/function";

const x = Function(() => {});
```

* * *

### apply

<code>apply(x<sup>0</sup><sub>any</sub>, x<sup>1</sup><sub>any</sub>, ..., x<sup>n</sup><sub>any</sub>).as*Type* ➜ x<sub>*type*</sub></code>

The **apply** operator allows to create a boolean expression which evals to the result of the function

```typescript
import {Function} from "@compute.ts/function";
import {number} from "@compute.ts/number";
import {string} from "@compute.ts/string";

const x = Function((y1: number, y2: string) => {
    let output = '';
    for(let i = 0; i < y1; i++) {
        output += y2;
    }
    return output;
});

const y1 = number();
const y2 = string();

const y = x.apply(y1, y2).asString;

const value = y.eval();
```

* * *

![](https://colibri-engine.com/assets/img/brand/logo_animated.gif)
